module.exports = defineTest({
	description: 'maintains live bindings'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/bindings
